@echo off
REM ***************************************************************************
REM *  IBM/HCL Confidential
REM *  OCO Source Materials
REM *
REM *  Licensed Materials - Property of IBM and/or HCL
REM *  (c) Copyright IBM Corporation 2005, 2016. All Rights Reserved.
REM *  (c) Copyright HCL Technologies Ltd. 2017, 2018. All Rights Reserved.
REM *
REM *  Note to U.S. Government Users Restricted Rights:
REM *  Use, duplication or disclosure restricted by GSA ADP Schedule
REM *  Contract with IBM Corp.
REM *
REM *
REM *  This batch file compiles all maps for the SEPA EPC example maps.
REM *
REM *  Prior to running this script, download the EPC schemas from SEPA and place them in the "ct" and/or "dd" subdirectories.
REM *
REM ***************************************************************************

rem cd to the directory this batch file is running from
rem cd /d %~dp0 - use this if the pushd doesn't work
pushd "%~dp0"

set mapsDir=%CD%
set LOG="%mapsDir%\build_deploy_epc_mapsandschemas.log"
rem - clear out old log file...
if exist %LOG% del /f /q %LOG%


set PLATFORM=%1
set TARGET=%2
@rem ==========================================================================
if not defined PLATFORM goto :UsageError
if     (%PLATFORM%)==() goto :UsageError

if not defined TARGET goto :UsageError
if     (%TARGET%)==() goto :UsageError

REM "PLATFORM = AIX|HPUX|SOLARIS|ZOS|LINUX|ZLINUX|HPITANIUM|WINDOWS"
if %PLATFORM%==AIX       goto :ValidPlatform
if %PLATFORM%==HPUX      goto :ValidPlatform
if %PLATFORM%==SOLARIS   goto :ValidPlatform
if %PLATFORM%==ZOS       goto :ValidPlatform
if %PLATFORM%==LINUX     goto :ValidPlatform
if %PLATFORM%==ZLINUX    goto :ValidPlatform
if %PLATFORM%==HPITANIUM goto :ValidPlatform
if %PLATFORM%==WINDOWS   goto :ValidPlatform
goto :UsageError

:ValidPlatform

REM "TARGET = ct|dd|both"
if %TARGET%==ct   goto :ValidTarget
if %TARGET%==dd   goto :ValidTarget
if %TARGET%==both goto :ValidTarget
goto :UsageError

:ValidTarget
set MAPEXT=.xxx
if %PLATFORM%==AIX       set MAPEXT=.aix
if %PLATFORM%==HPUX      set MAPEXT=.hp
if %PLATFORM%==SOLARIS   set MAPEXT=.sun
if %PLATFORM%==ZOS       set MAPEXT=.mvs
if %PLATFORM%==LINUX     set MAPEXT=.lnx
if %PLATFORM%==ZLINUX    set MAPEXT=.znx
if %PLATFORM%==HPITANIUM set MAPEXT=.hpi
if %PLATFORM%==WINDOWS   set MAPEXT=.mmc

echo Platform is %PLATFORM% and map extension is %MAPEXT% >> %LOG%
echo Target directory is %TARGET% >> %LOG%

set TARGETCT=FALSE
set TARGETDD=FALSE
if %TARGET%==ct   set TARGETCT=TRUE
if %TARGET%==both set TARGETCT=TRUE
if %TARGET%==dd   set TARGETDD=TRUE
if %TARGET%==both set TARGETDD=TRUE

if %TARGETCT%==TRUE (
    if not exist ct\*.xsd  goto :TargetSchemasNotFound
)
if %TARGETDD%==TRUE (
    if not exist dd\*.xsd  goto :TargetSchemasNotFound
)

rem cd to the base directory to get the location of mcompile.exe
cd ..\..\..\..\..\..\
rem check to make sure mcompile is where we expect it
if exist "%CD%\mcompile.exe" (
    set DTX_HOME=%CD%
	echo DTXHOME is: %CD% >> %LOG%
) else (
	goto :MCompileNotFound
)
rem return to maps directory
cd "%mapsDir%"


echo === Starting EPC mapsandschemas map build...

rem copy schemas to main dir (will override if already present)
echo     Copying schema files from examples to the main mapsandschemas directory
echo Copying schema files from examples to the main mapsandschemas directory >> %LOG%
if %TARGETCT%==TRUE (
    if not exist ..\..\..\mapsandschemas\ct mkdir ..\..\..\mapsandschemas\ct >> %LOG%
    copy ct\*.xsd ..\..\..\mapsandschemas\ct /Y >> %LOG%
    copy ct\*.mtx ..\..\..\mapsandschemas\ct /Y >> %LOG%
)
if %TARGETDD%==TRUE (
    if not exist ..\..\..\mapsandschemas\dd mkdir ..\..\..\mapsandschemas\dd >> %LOG%
    copy dd\*.xsd ..\..\..\mapsandschemas\dd /Y >> %LOG%
    copy dd\*.mtx ..\..\..\mapsandschemas\dd /Y >> %LOG%
)

rem copy map source to main dir (prompt to replace if already exists)
echo     Copying epc_sepa_validation.mms from examples directory to main mapsandschemas directory
echo Copying epc_sepa_validation.mms from examples directory to main mapsandschemas directory >> %LOG%
copy /-Y epc_sepa_validation.mms ..\..\..\mapsandschemas
echo.

rem build epc_sepa_validation.mms in main mapsandschemas directory
cd "%mapsDir%\..\..\..\mapsandschemas" >> %LOG%
set MCOMPILE="%DTX_HOME%\mcompile.exe"
echo mcompile.exe location is: %MCOMPILE% >> %LOG%
set mcompileOptions= -A -E -K -P %PLATFORM%
echo     Building epc_sepa_validation.mms for platform %PLATFORM%
echo Building epc_sepa_validation.mms for platform %PLATFORM% >> %LOG%
%MCOMPILE% epc_sepa_validation.mms %mcompileOptions% >> %LOG%

cd "%mapsDir%"

echo === Finished EPC mapsandschemas map build.
echo.
goto :Run_EXIT

:MCompileNotFound
echo.
echo base directory not found!
echo This script must run from the SEPA component examples subdirectory: examples\epc_mapsandschemas\mapsandschemas.
echo Example: "<base product install dir>\packs\financial_payments_v<version>\sepa\examples\epc_mapsandschemas\mapsandschemas"
echo.
goto :EOF

:TargetSchemasNotFound
echo.
echo Target schemas not found!
if %TARGET%==ct (
    echo This script requires *.xsd schema files to be found in %TARGET% directory
    echo Example: "<base product install dir>\packs\financial_payments_v<version>\sepa\examples\epc_mapsandschemas\mapsandschemas\%TARGET%"
    echo.
    goto :EOF
)
if %TARGET%==dd (
    echo This script requires *.xsd schema files to be found in %TARGET% directory
    echo Example: "<base product install dir>\packs\financial_payments_v<version>\sepa\examples\epc_mapsandschemas\mapsandschemas\%TARGET%"
    echo.
    goto :EOF
)
if %TARGET%==both (
    echo This script requires *.xsd schema files to be found in both ct and dd directories
    echo Example: "<base product install dir>\packs\financial_payments_v<version>\sepa\examples\epc_mapsandschemas\mapsandschemas\ct"
    echo Example: "<base product install dir>\packs\financial_payments_v<version>\sepa\examples\epc_mapsandschemas\mapsandschemas\dd"
    echo.
    goto :EOF
)
goto :EOF

:Run_EXIT

echo === Map build script completed. See log file: %LOG% for details.
echo.
goto :EOF

:UsageError
echo.
echo "USAGE: %0 <PLATFORM> <TARGET>"
echo "where: PLATFORM = AIX|HPUX|SOLARIS|ZOS|LINUX|ZLINUX|HPITANIUM|WINDOWS"
echo "       TARGET   = ct|dd|both"
echo.
goto :EOF


:EOF
