/* 
 * Licensed Materials - Property of IBM and/or HCL 
 * (c) Copyright IBM Corporation 2005, 2019. All Rights Reserved. 
 * (c) Copyright HCL Technologies Ltd. 2017,2019. All Rights Reserved. 
 *  
 * Note to U.S. Government Users Restricted Rights: 
 * Use, duplication or disclosure restricted by GSA ADP Schedule 
 * Contract with IBM Corp.
 *
 */
#include "shredder.hpp"
#include "XMLDHI.hpp"

#include <xercesc/util/PlatformUtils.hpp>

XERCES_CPP_NAMESPACE_USE


// The entry point for the console application //////////////////////////////

int main(int argc, char* argv[])
{
  char
      xmlUrl[MAX_PATH] = {'\0'}
    , headerUrl[MAX_PATH] = {'\0'}
    , trailerUrl[MAX_PATH] = {'\0'}
    , elemName[256]= {'\0'}
    , errMsg[65536] = {'\0'};
  XMLDocumentHandlerImpl* docHandler = 0;
  unsigned int maxSize = ANY_SIZE;
  unsigned int result = 0;

#ifdef __MVS__
  int rc = setenv("_IXM_FORCE_CONVERSION", "USE_ICU_SRC_OFFS", 1);
  strcpy(xmlUrl, "DD:");
#endif

  if (argc == 2)
  {
    strcat(xmlUrl, argv[1]);
  }
  else if (argc == 3)
  {
    strcat(xmlUrl, argv[1]);
    maxSize = atol(argv[2]);
  }
  else
  {
    fprintf(stderr, "Usage: shredder <xml file name> [maximum size]\n");
    return -1;
  }

  // Initialize xml4c
  //
  try
  {
    XMLPlatformUtils::Initialize();

    // Create the XML Document Handler
    docHandler = new XMLDocumentHandlerImpl();
    if (docHandler)
    {
      result = docHandler->parse(xmlUrl, maxSize, errMsg);

      // Check the result
      if (strlen(errMsg) == 0)
        fprintf(stderr, "Validation succeeded\n");
      else
        fprintf(stderr, errMsg);
    }
  }
  catch (XMLException& ex)
  {
    strcpy(errMsg, XMLString::transcode(ex.getMessage()));
    fprintf(stderr, errMsg);
  }

  // Terminate xml4c
  try
  {
    if (docHandler)
      delete docHandler;
    
    XMLPlatformUtils::Terminate();
  }
  catch (XMLException& ex)
  {
    strcpy(errMsg, XMLString::transcode(ex.getMessage()));
    fprintf(stderr, errMsg);
    return -1;
  }
	return result;
}

