@echo off
REM ***************************************************************************
REM *  Licensed Materials - Property of IBM and/or HCL
REM *  (c) Copyright IBM Corporation 2005, 2019. All Rights Reserved.
REM *  (c) Copyright HCL Technologies Ltd. 2017, 2019. All Rights Reserved.
REM *
REM *  Note to U.S. Government Users Restricted Rights:
REM *  Use, duplication or disclosure restricted by GSA ADP Schedule
REM *  Contract with IBM Corp.
REM *
REM *
REM *  This batch file compiles all maps for the SWIFT MX validation checking.
REM *  After the map build, the deployment step performs an FTP copy of all of
REM *  the files needed for the system to run.
REM *
REM *  There are 5 parameters needed for this script to execute.
REM *  Any or all of these parameters can be set through command line,
REM *  or can be hard-coded in the set values below.
REM *
REM *  This batch file takes 1 mandatory and 4 optional parameters:
REM *  1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
REM *  2 = Operating system user name (if no user name is given, then it is assumed
REM *      the deployment step is not required, and parameters 3 - 5 will not be needed.
REM *  3 = Operating system password
REM *  4 = FTP Server location
REM *  5 = top level directory to deploy map files, schemas, and supporting files
REM *
REM *  NOTE: The script is designed to use paths without spaces for parameter 5.
REM *  Further modification is needed to this script and the ftp template script
REM *   if path names with spaces is to be used.
REM *
REM *  NOTE: For parameter 5, under this top level directory specified, the files
REM *  will be deployed to a sub folder called mx, and distributed to other
REM *  folders underneath this mx folder.
REM *  EXAMPLE call to the script with all parameters passed:
REM *  build_deploy_mx_validation.bat AIX username password UNIXMACHINE /usr/apps/base/packs/swift
REM *
REM *  NOTE: If only the first parameter is passed, and the OS Platform value is WINDOWS, then the
REM *  deployment files will be placed in a local deployment directory and also be placed
REM *  in the default locations that the base maps use so that users can execute the maps directly
REM *  after running this script without having to move any dependent files.
REM ***************************************************************************

set dash=-------------------------------------------------------

rem set OS platform - parameter 1
set deploy=true
rem test the platform passed in to ensure it is a valid value

set PLATFORM=%1
if not defined   PLATFORM    goto :Error_PlatformNotSpecified

rem - set FTP location's OS user account and password. Parameters 2 and 3
set USER=%2
if not defined   USER    goto :no_deploy_params_setup

set PASSWORD=%3
if not defined   PASSWORD    goto :Error_PasswordNotSpecified

rem set FTP server location - Parameter 4
set FTP_SERVER=%4
if not defined   FTP_SERVER    goto :Error_ServerNotSpecified

rem - set target directory for deployment. Parameter 5
set baseDIR=%5
if not defined   baseDIR    goto :Error_PathNotSpecified

if defined USER    goto :skip_no_deploy_setup

:no_deploy_params_setup
set deploy=false

:skip_no_deploy_setup

set LOG=build_deploy_mx_validation.log
rem - clear out old log file...
if exist %LOG% del /f /q %LOG%
rem - create new log file and header for specific base version...
echo Build and Deploying Pack for Financial Payments - SWIFT Component MX validation on %PLATFORM% > %LOG%
echo FTP Server: %FTP_SERVER% >> %LOG%
echo Using directory: %baseDIR% >> %LOG%
echo %dash% >> %LOG%
echo Start time is: >> %LOG%
time /T >> %LOG%
DATE /T >> %LOG%
echo %dash% >> %LOG%

rem cd to the directory this batch file is running from
rem cd /d %~dp0 - use this if the pushd doesn't work
pushd "%~dp0"

set mapsDir=%CD%

rem cd to the base directory to get the location of mcompile.exe
cd ..\..\..\..\..\

rem check to make sure mcompile is where we expect it
if exist "%CD%\mcompile.exe" (
    set DTX_HOME=%CD%
) else (
	goto :MCompileNotFound
)

rem set up the directories for all of the files that need to be moved
cd "%mapsDir%"

rem create a directory to hold all of the files that will be deployed

if not exist "%mapsDir%\deployment_mx_validation" (
	mkdir deployment_mx_validation
	mkdir deployment_mx_validation\maps
	mkdir deployment_mx_validation\schemas
	mkdir deployment_mx_validation\data
	)

set DeployDir=%mapsDir%\deployment_mx_validation

REM if exist "%mapsDir%\deployment_mx_validation" (
REM		set DeployDir=%mapsDir%\deployment_mx_validation
REM		echo DEPLOY EXISTS: %DeployDir%
REM		)
REM	else echo DEPLOYMENT DIRECTORY WAS NOT ABLE TO BE CREATED!

rem cd to the schemas folder and set the SchemaDir
cd ..\schemas
set SchemaDir=%CD%

rem cd to the data folder and set the DataDir
cd ..\data
set DataDir=%CD%

rem cd to the common folder and set the CommonDir
cd ..\..\common
set CommonDir=%CD%

cd %mapsDir%

rem *********************************MAP BUILD**************************************
echo *********************************MAP BUILD************************************** >> %LOG%
echo schema directory is:      %SchemaDir% >> %LOG%
echo data directory is:        %DataDir% >> %LOG%
echo common directory is:      %CommonDir% >> %LOG%
echo deployment directory is:  %DeployDir% >> %LOG%
echo Pack for Financial Payments - SWIFT component maps directory is: %mapsDir% >> %LOG%
echo.
echo %dash%
echo === Starting map build...
echo.
set MCOMPILE="%DTX_HOME%\mcompile.exe"
echo mcompile.exe location is: %MCOMPILE% >> %LOG%
set mcompileOptions= -P %PLATFORM% -A -E -O "%DeployDir%\maps\*.mmc"
%MCOMPILE% mx_validation_framework.mms %mcompileOptions% >> %LOG%
echo === Finished mx_validation_framework maps build.
%MCOMPILE% mx_acmt_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_acmt_validation maps build.
%MCOMPILE% mx_camt_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_camt_validation maps build.
%MCOMPILE% mx_colr_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_colr_validation maps build.
%MCOMPILE% mx_e_i_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_e_i_validation maps build.
%MCOMPILE% mx_head_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_head_validation maps build.
%MCOMPILE% mx_pacs_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_pacs_validation maps build.
%MCOMPILE% mx_pain_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_pain_validation maps build.
%MCOMPILE% mx_reda_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_reda_validation maps build.
%MCOMPILE% mx_secl_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_secl_validation maps build.
%MCOMPILE% mx_seev_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_seev_validation maps build.
%MCOMPILE% mx_semt_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_semt_validation maps build.
%MCOMPILE% mx_sese_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_sese_validation maps build.
%MCOMPILE% mx_setr_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_setr_validation maps build.
%MCOMPILE% mx_tsmt_validation.mms %mcompileOptions% >> %LOG%
echo === Finished mx_tsmt_validation maps build.
echo.
echo === Finished map build.
echo.


rem ********************************COPY FILES**************************************
echo *********************************COPY FILES************************************* >> %LOG%
echo %dash%
echo.
echo === Copying files to deployment directory...

xcopy /r /y  "%mapsDir%\mx_validation_errcodes.txt" "%DeployDir%\maps" >> %LOG%
xcopy /r /y  "%mapsDir%\mxconfig.xml" "%DeployDir%\maps" >> %LOG%
xcopy /r /y  "%DataDir%\*.xml" "%DeployDir%\data" >> %LOG%
xcopy /r /y  "%SchemaDir%\*.xsd" "%DeployDir%\schemas" >> %LOG%
xcopy /r /y  "%CommonDir%\schemas\*.xsd" "%DeployDir%\schemas" >> %LOG%
xcopy /r /y  "%CommonDir%\data\*.xml" "%DeployDir%\maps" >> %LOG%

if %deploy% == false goto :skipDeploy
rem ********************************DEPLOYMENT**************************************
echo *********************************DEPLOYMENT************************************* >> %LOG%
echo.
echo %dash%
echo.
echo === Starting deployment...
echo.

rem ============================================================================
rem :DeployToUnix
rem create the ftp script to run with the user name, password and server
rem to copy all artifacts to remote servers
rem ============================================================================

:DeployToUnix

echo Preparing FTP script to deploy all SWIFT MX validation artifacts to %PLATFORM% - %FTP_SERVER%...
call :BatchSubstitute "#FTP_SERVER#" %FTP_SERVER% FTP_unix_deploy_mx_template.scp > start.scp
call :BatchSubstitute "#USER#" %USER% start.scp > user.scp
del start.scp
call :BatchSubstitute "#PASSWORD#" %PASSWORD% user.scp > pw.scp
del user.scp
call :BatchSubstitute "#SERVERHOME#" %baseDIR% pw.scp > basedir.scp
del pw.scp
for %%f in ("%DeployDir%") do set ShortMapDir=%%~sf
call :BatchSubstitute "#DEPLOYDIR#" %ShortMapDir% basedir.scp > deploy.scp
del basedir.scp

echo Created temporary FTP script. >> %LOG%


echo Running FTP script to deploy all SWIFT MX validation artifacts to %PLATFORM% - %FTP_SERVER%...
echo Running FTP script to deploy all SWIFT MX validation artifacts to %PLATFORM% - %FTP_SERVER%... >> %LOG%

REM ===========================================================================
REM If using Secure FTP, uncomment out the next line and modify according to
REM your SFTP client command line options.
REM ===========================================================================

REM psftp %USER%@%FTP_SERVER% -pw %PASSWORD% -bc -be -b deploy.scp >> %LOG%

ftp -s:deploy.scp  >> %LOG%

REM ===========================================================================
REM for troubleshooting FTP issues, comment out the next line and
REM analyze the file deploy.scp
REM ===========================================================================
del deploy.scp

goto :Run_EXIT

rem ============================================================================
rem :BatchSubstitute
rem  Text string find/replace.
rem ============================================================================

:BatchSubstitute

REM -- Prepare the Command Processor --
setLOCAL ENABLEEXTENSIONS
setLOCAL DISABLEDELAYEDEXPANSION

if "%*"=="" findstr "^::" "%~f0"&GOTO:EOF
for /f "tokens=1,* delims=]" %%A in ('"type %3|find /n /v """') do (
    set "line=%%B"
    if defined line (
        call set "line=echo.%%line:%~1=%~2%%"
        for /f "delims=" %%X in ('"echo."%%line%%""') do %%~X
    ) ELSE echo.
)

goto :EOF

:Error_UserNotSpecified
set ERROR=No OS User specified.
goto :Print_Error

:Error_PasswordNotSpecified
set ERROR=No OS Password specified.
goto :Print_Error

:Error_PlatformNotSpecified
set ERROR=No OS Platform specified.
goto :Print_Error

:Error_ServerNotSpecified
set ERROR=No FTP Server location specified.
goto :Print_Error

:Error_PathNotSpecified
set ERROR=No top level directory specified.
goto :Print_Error

:Print_Error
echo.
echo %dash%
echo Error: %ERROR%
echo %dash%
goto :Print_Params

:Print_Params
echo.
echo This batch file takes 5 parameters:
echo.
echo 1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
echo.
echo 2 = Operating system user name
echo.
echo 3 = Operating system password
echo.
echo 4 = FTP Server location
echo.
echo 5 = top level directory to deploy map files, schemas, and supporting files
echo.
echo EXAMPLE: build_deploy_mx_validation.bat AIX username password  UNIXMACHINE /usr/bin/base/packs/swift
goto :EOF

:MCompileNotFound
echo %dash%
echo.
echo base directory not found!
echo This script must run from the SWIFT component default installation subdirectory: mx\maps.
echo Example: "<base product install dir>\packs\financial_payments_v<version>\swift\mx\maps"
echo.
echo %dash%
goto :EOF

:skipDeploy
echo Skipping FTP deployment of all SWIFT MX Validation artifacts...
echo Skipping FTP deployment of all SWIFT MX Validation artifacts... >> %LOG%

rem for WINDOWS only, copy from the deployment folder:
rem  *.mmc to mx\maps
rem   schemas\bic.xsd and schemas\ccy.xsd to mx\schemas
rem this ensures that the WINDOWS user will be able to run the validation with default settings and path locations.

if /I %PLATFORM% EQU WINDOWS goto :CopyLocal
goto :EOF

:CopyLocal
echo.
echo %PLATFORM% build specified. Copying files to default local directory.
echo.  >> %LOG%
echo %PLATFORM% build specified. Copying files to default local directory. >> %LOG%
xcopy /r /y  "%DeployDir%\maps\*.mmc" "%mapsDir%"  >> %LOG%
xcopy /r /y  "%CommonDir%\schemas\*.xsd" "%SchemaDir%" >> %LOG%
xcopy /r /y  "%CommonDir%\data\*.xml" "%mapsDir%" >> %LOG%

:Run_EXIT

echo %dash%
echo === Map compile and deploy script completed
echo.
echo === The log of actions titled build_deploy_mx_validation.log is located at %CD%
echo %dash%
goto :EOF
